﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Telerik.Windows.Data;
using Telerik.Windows.Controls;
using Telerik.Windows.Controls.DragDrop;
using Telerik.Windows.Controls.GridView;
using System.Collections;

namespace RadGridView_DnDGrids
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();

            this.playersGrid1.ItemsSource = Player.GetPlayers1();
            this.playersGrid2.ItemsSource = Player.GetPlayers2();

            RadDragAndDropManager.AddDropQueryHandler(this.playersGrid1, RadGridView_OnDropQuery);
            RadDragAndDropManager.AddDropInfoHandler(this.playersGrid1, RadGridView_OnDropInfo);
            RadDragAndDropManager.AddDragQueryHandler(this.playersGrid1, OnGridViewDragQuery);
            RadDragAndDropManager.AddDragInfoHandler(this.playersGrid1, OnGridViewDragInfo);

            RadDragAndDropManager.AddDropQueryHandler(this.playersGrid2, RadGridView_OnDropQuery);
            RadDragAndDropManager.AddDropInfoHandler(this.playersGrid2, RadGridView_OnDropInfo);
            RadDragAndDropManager.AddDragQueryHandler(this.playersGrid2, OnGridViewDragQuery);
            RadDragAndDropManager.AddDragInfoHandler(this.playersGrid2, OnGridViewDragInfo);
        }

        private void OnGridViewDragQuery(object sender, DragDropQueryEventArgs e)
        {
            var draggedItem = e.Options.Source;
            if (e.Options.Status == DragStatus.DragQuery)
            {
                e.QueryResult = !(draggedItem is GridViewGroupRow);
                e.Handled = true;

                // Create Drag and Arrow Cue
                ContentControl dragCue = new ContentControl();
                dragCue.Content = draggedItem.DataContext;
                dragCue.ContentTemplate = this.Resources["DragCueTemplate"] as DataTemplate;
                e.Options.DragCue = dragCue;
                e.Options.ArrowCue = RadDragAndDropManager.GenerateArrowCue();

                e.Options.Payload = draggedItem.DataContext;
            }

            if (e.Options.Status == DragStatus.DropSourceQuery)
            {
                e.QueryResult = true;
                e.Handled = true;
            }


        }

        private void OnGridViewDragInfo(object sender, DragDropEventArgs e)
        {
            RadGridView gridView = sender as RadGridView;
            Player draggedItem = e.Options.Payload as Player;

            if (e.Options.Status == DragStatus.DragComplete)
            {
                IList source = gridView.ItemsSource as IList;
                if (source.Contains(draggedItem))
                {
                    source.Remove(draggedItem);
                }
                gridView.Rebind();
            }
        }

        private void RadGridView_OnDropQuery(object sender, DragDropQueryEventArgs e)
        {
            RadGridView destination = sender as RadGridView;

            if (destination != null)
            {
                e.Handled = true;
                e.QueryResult = true;
            }
        }

        private void RadGridView_OnDropInfo(object sender, DragDropEventArgs e)
        {
            RadGridView destination = sender as RadGridView;
            if (e.Options.Status == DragStatus.DropComplete)
            {
                (destination.ItemsSource as IList<Player>).Add(e.Options.Payload as Player);
            }
        }
    }
}
